@@ -1,4 +1,7 @@
-from django.conf.urls.defaults import patterns, url, include
+try:
+    from django.conf.urls.defaults import patterns, url, include
+except ImportError:  # django 1.6 and above
+    from django.conf.urls import patterns, url, include
 from django.contrib import admin
 
 
